ModelSurvey class

Constructors

ModelSurvey({required dynamic type, required dynamic prompt, required dynamic options, required dynamic isReq})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isReq → dynamic
final
options → dynamic
final
prompt → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited