ConfigConstants class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- backgroundBlue → const Color
- backgroundOrange → const Color
- backgroundRed → const Color
- black → const Color
- fontCheckoutButton → const double
- fontDialogDescription → const double
- fontDialogTitle → const double
- fontHomeGreeting → const double
- fontLarge → const double
- fontToastMessage → const double
- gradient1 → const Color
- gradient2 → const Color
- gradient3 → const Color
- green → const Color
- greyDark → const Color
- greyDarkest → const Color
- greyLight → const Color
- greyLightest → const Color
- lightPurple → const Color
- loginGradientBackground → const BoxDecoration
- offWhite → const Color
- orange → const Color
- paddingGeneral → const double
- pink → const Color
- purple → const Color
- purpleDark → const Color
- purpleLight → const Color
- red → const Color
- salmon → const Color
- white → const Color